@@ -8,12 +8,10 @@ from typing import (
     Generic,
     Literal,
     TypeVar,
-    Union,
     cast,
 )
 
 import pystac
-from pystac.extensions import item_assets
 from pystac.extensions.base import (
     ExtensionManagementMixin,
     PropertiesExtension,
@@ -24,7 +22,9 @@ from pystac.serialization.identify import STACJSONDescription, STACVersionID
 from pystac.summaries import RangeSummary
 from pystac.utils import StringEnum, get_required, map_opt
 
-T = TypeVar("T", pystac.Item, pystac.Asset, item_assets.AssetDefinition)
+#: Generalized version of :class:`~pystac.Item`, :class:`~pystac.Asset` or
+#: :class:`~pystac.ItemAssetDefinition`
+T = TypeVar("T", pystac.Item, pystac.Asset, pystac.ItemAssetDefinition)
 
 SCHEMA_URI: str = "https://stac-extensions.github.io/sar/v1.0.0/schema.json"
 PREFIX: str = "sar:"
@@ -73,7 +73,7 @@ class ObservationDirection(StringEnum):
 class SarExtension(
     Generic[T],
     PropertiesExtension,
-    ExtensionManagementMixin[Union[pystac.Item, pystac.Collection]],
+    ExtensionManagementMixin[pystac.Item | pystac.Collection],
 ):
     """An abstract class that can be used to extend the properties of an
     :class:`~pystac.Item` or :class:`~pystac.Asset` with properties from the
@@ -81,13 +81,13 @@ class SarExtension(
     STAC Object to be extended (e.g. :class:`~pystac.Item`,
     :class:`~pystac.Asset`).
 
-    To create a concrete instance of :class:`SARExtension`, use the
-    :meth:`SARExtension.ext` method. For example:
+    To create a concrete instance of :class:`SarExtension`, use the
+    :meth:`SarExtension.ext` method. For example:
 
     .. code-block:: python
 
        >>> item: pystac.Item = ...
-       >>> sar_ext = SARExtension.ext(item)
+       >>> sar_ext = SarExtension.ext(item)
     """
 
     name: Literal["sar"] = "sar"
@@ -332,7 +332,7 @@ class SarExtension(
                 )
             cls.ensure_owner_has_extension(obj, add_if_missing)
             return cast(SarExtension[T], AssetSarExtension(obj))
-        elif isinstance(obj, item_assets.AssetDefinition):
+        elif isinstance(obj, pystac.ItemAssetDefinition):
             cls.ensure_owner_has_extension(obj, add_if_missing)
             return cast(SarExtension[T], ItemAssetsSarExtension(obj))
         else:
@@ -348,12 +348,12 @@ class SarExtension(
 
 
 class ItemSarExtension(SarExtension[pystac.Item]):
-    """A concrete implementation of :class:`SARExtension` on an :class:`~pystac.Item`
+    """A concrete implementation of :class:`SarExtension` on an :class:`~pystac.Item`
     that extends the properties of the Item to include properties defined in the
     :stac-ext:`SAR Extension <sar>`.
 
     This class should generally not be instantiated directly. Instead, call
-    :meth:`SARExtension.ext` on an :class:`~pystac.Item` to extend it.
+    :meth:`SarExtension.ext` on an :class:`~pystac.Item` to extend it.
     """
 
     item: pystac.Item
@@ -371,12 +371,12 @@ class ItemSarExtension(SarExtension[pystac.Item]):
 
 
 class AssetSarExtension(SarExtension[pystac.Asset]):
-    """A concrete implementation of :class:`SARExtension` on an :class:`~pystac.Asset`
+    """A concrete implementation of :class:`SarExtension` on an :class:`~pystac.Asset`
     that extends the Asset fields to include properties defined in the
     :stac-ext:`SAR Extension <sar>`.
 
     This class should generally not be instantiated directly. Instead, call
-    :meth:`SARExtension.ext` on an :class:`~pystac.Asset` to extend it.
+    :meth:`SarExtension.ext` on an :class:`~pystac.Asset` to extend it.
     """
 
     asset_href: str
@@ -399,19 +399,19 @@ class AssetSarExtension(SarExtension[pystac.Asset]):
         return f"<AssetSarExtension Asset href={self.asset_href}>"
 
 
-class ItemAssetsSarExtension(SarExtension[item_assets.AssetDefinition]):
+class ItemAssetsSarExtension(SarExtension[pystac.ItemAssetDefinition]):
     properties: dict[str, Any]
-    asset_defn: item_assets.AssetDefinition
+    asset_defn: pystac.ItemAssetDefinition
 
-    def __init__(self, item_asset: item_assets.AssetDefinition):
+    def __init__(self, item_asset: pystac.ItemAssetDefinition):
         self.asset_defn = item_asset
         self.properties = item_asset.properties
 
 
 class SummariesSarExtension(SummariesExtension):
-    """A concrete implementation of :class:`~SummariesExtension` that extends
-    the ``summaries`` field of a :class:`~pystac.Collection` to include properties
-    defined in the :stac-ext:`SAR Extension <sar>`.
+    """A concrete implementation of :class:`~pystac.extensions.base.SummariesExtension`
+    that extends the ``summaries`` field of a :class:`~pystac.Collection` to include
+    properties defined in the :stac-ext:`SAR Extension <sar>`.
     """
 
     @property
