@@ -78,9 +78,9 @@ def _migrate_datetime_range(
     return None
 
 
-def _get_object_migrations() -> (
-    dict[str, Callable[[dict[str, Any], STACVersionID, STACJSONDescription], None]]
-):
+def _get_object_migrations() -> dict[
+    str, Callable[[dict[str, Any], STACVersionID, STACJSONDescription], None]
+]:
     return {
         pystac.STACObjectType.CATALOG: _migrate_catalog,
         pystac.STACObjectType.COLLECTION: _migrate_collection,
@@ -88,21 +88,19 @@ def _get_object_migrations() -> (
     }
 
 
-def _get_removed_extension_migrations() -> (
-    dict[
-        str,
-        tuple[
-            list[STACObjectType] | None,
-            None
-            | (
-                Callable[
-                    [dict[str, Any], STACVersionID, STACJSONDescription],
-                    set[str] | None,
-                ]
-            ),
-        ],
-    ]
-):
+def _get_removed_extension_migrations() -> dict[
+    str,
+    tuple[
+        list[STACObjectType] | None,
+        None
+        | (
+            Callable[
+                [dict[str, Any], STACVersionID, STACJSONDescription],
+                set[str] | None,
+            ]
+        ),
+    ],
+]:
     """Handles removed extensions.
 
     This does not handle renamed extension or extensions that were absorbed
