@@ -587,7 +587,11 @@ class STACObject(ABC):
         jinja_env = get_jinja_env()
         if jinja_env:
             template = jinja_env.get_template("JSON.jinja2")
-            return str(template.render(dict=self.to_dict(transform_hrefs=False)))
+            return str(
+                template.render(
+                    dict=self.to_dict(transform_hrefs=False), plain=escape(repr(self))
+                )
+            )
         else:
             return escape(repr(self))
 
