@@ -214,6 +214,6 @@ class TestCases:
         """Planet disaster data example catalog, 1.0.0-beta.2"""
         return Collection.from_file(
             TestCases.get_path(
-                "data-files/catalogs/" "planet-example-v1.0.0-beta.2/collection.json"
+                "data-files/catalogs/planet-example-v1.0.0-beta.2/collection.json"
             )
         )
